Tutorials
=========

This folder contains several tutorials on how to use the GeoWATCH system to train simple fusion models:

-  Tutorial 1: Generate toy RGB data and fit a simple network  |Tutorial1_Shell| |Tutorial1_Jupyter| |Tutorial1_Colab|

-  Tutorial 2: Generate toy multi-spectral data and fit a simple network |Tutorial2_Shell|

-  Tutorial 3: Fuse features from multiple sources |Tutorial3_Shell|

-  Tutorial 4: Advanced Training |Tutorial4_Shell|

-  Tutorial 5: IARPA SMART Demo |Tutorial5_Shell| |Tutorial5_Colab|

-  Tutorial 6: KHQ SMART Demo |Tutorial6_Shell|

  * See Also: `KQH Demo Slides <https://docs.google.com/presentation/d/1HKH_sGJX4wH60j8t4iDrZN8nH71jGX1vbCXFRIDVI7c/edit#slide=id.p>`_.


TODO: tutorial about kwcoco (See docs for `kwcoco <https://gitlab.kitware.com/computer-vision/kwcoco>`_)


SeeAlso SMART-specific tutorials:

* `SMART Activity Characterization Tutorial <../smart/smart_ac_tutorial.rst>`_

* `SMART Ensemble Tutorial <../smart/smart_ensemble_tutorial.rst>`_

.. |Tutorial1_Jupyter| image:: https://img.shields.io/badge/jupyter-%23FA0F00.svg?style=for-the-badge&logo=jupyter&logoColor=white
    :target: tutorial1_rgb_network.ipynb

.. |Tutorial1_Shell| image:: https://img.shields.io/badge/shell_script-%23121011.svg?style=for-the-badge&logo=gnu-bash&logoColor=white
    :target: tutorial1_rgb_network.sh

.. |Tutorial1_Colab| image:: https://colab.research.google.com/assets/colab-badge.svg
    :target: https://colab.research.google.com/drive/1zGgs47WglRf3lLpjS3vHUmgxIM4oziBH?usp=share_link

.. |Tutorial2_Shell| image:: https://img.shields.io/badge/shell_script-%23121011.svg?style=for-the-badge&logo=gnu-bash&logoColor=white
    :target: tutorial2_msi_network.sh

.. |Tutorial3_Shell| image:: https://img.shields.io/badge/shell_script-%23121011.svg?style=for-the-badge&logo=gnu-bash&logoColor=white
    :target: tutorial3_feature_fusion.sh

.. |Tutorial4_Shell| image:: https://img.shields.io/badge/shell_script-%23121011.svg?style=for-the-badge&logo=gnu-bash&logoColor=white
    :target: tutorial4_advanced_training.sh

.. |Tutorial5_Shell| image:: https://img.shields.io/badge/shell_script-%23121011.svg?style=for-the-badge&logo=gnu-bash&logoColor=white
    :target: tutorial5_bas_prediction.sh

.. |Tutorial5_Colab| image:: https://colab.research.google.com/assets/colab-badge.svg
    :target: https://colab.research.google.com/drive/1SiNUDCn1sBMu2wybB8dyal6CM-fqAj1Y?usp=share_link

.. |Tutorial6_Shell| image:: https://img.shields.io/badge/shell_script-%23121011.svg?style=for-the-badge&logo=gnu-bash&logoColor=white
    :target: tutorial6_predict_KHQ.sh

.. * Tutorial 1: `Toy RGB Tutorial <tutorial1_rgb_network.sh>`_
.. * Tutorial 2: `Toy MSI Tutorial <tutorial2_msi_network.sh>`_
.. * Tutorial 3: `Feature Fusion Tutorial <tutorial3_feature_fusion.sh>`_
.. * Tutorial 4: `Advanced Training <tutorial4_advanced_training.sh>`_
.. * Tutorial 5: `BAS Prediction <tutorial5_bas_prediction.sh>`_
